@@ -14,7 +14,6 @@ from torch import nn
 from torch.nn import DataParallel
 from torch.utils.data import Dataset, SequentialSampler
 
-from dnn_cool.task_flow import TaskFlow
 from dnn_cool.utils import any_value
 
 
@@ -160,10 +159,10 @@ class TensorboardConverters:
 
         :param state: The state with which the callback is called.
         """
-        if (self.logdir is not None) and (state.loader_name not in self.loggers):
-            path = str(self.logdir / f"{state.loader_name}_log")
+        if (self.logdir is not None) and (state.loader_key not in self.loggers):
+            path = str(self.logdir / f"{state.loader_key}_log")
             writer = SummaryWriter(path)
-            self.loggers[state.loader_name] = writer
+            self.loggers[state.loader_key] = writer
 
     def publish(self, state: State, interpretations: Dict[str, torch.Tensor]):
         """
@@ -182,8 +181,8 @@ class TensorboardConverters:
             sorted_indices = value.argsort()
             best_indices = interpretations[f'indices|{key}'][sorted_indices][:self.top_k]
             worst_indices = interpretations[f'indices|{key}'][sorted_indices][-self.top_k:]
-            writer: SummaryWriter = self.loggers[state.loader_name]
-            dataset = self.datasets[state.loader_name]
+            writer: SummaryWriter = self.loggers[state.loader_key]
+            dataset = self.datasets[state.loader_key]
             self._publish_inputs(best_indices, writer, dataset, prefix='best', key=key)
             self._publish_inputs(worst_indices, writer, dataset, prefix='worst', key=key)
 
@@ -214,7 +213,7 @@ class InterpretationCallback(Callback):
     This callback publishes best and worst images per task, according to the configuration supplied via the constructor.
     """
 
-    def __init__(self, flow: TaskFlow,
+    def __init__(self, per_sample_criterion,
                  tensorboard_converters: Optional[TensorboardConverters] = None,
                  loaders_to_skip=()):
         """
@@ -226,10 +225,9 @@ class InterpretationCallback(Callback):
         :param loaders_to_skip: Optional loaders to be skipped, for example because labels aren't available for them.
         """
         super().__init__(CallbackOrder.Metric)
-        self.flow = flow
         self.loaders_to_skip = loaders_to_skip
 
-        self.overall_loss = flow.get_per_sample_loss()
+        self.overall_loss = per_sample_criterion
         self.leaf_losses = self.overall_loss.get_leaf_losses_per_sample()
         self.interpretations = {}
         self.loader_counts = {}
@@ -310,12 +308,12 @@ class DeviceReducingDataParallel(DataParallel):
         super().__init__(module)
         tasks_dict = task_flow.get_all_children()
         self.full_paths = []
-        for full_path, task in tasks_dict.items():
-            if task.is_train_only():
+        for full_path, task_for_development in tasks_dict.items():
+            if task_for_development.task.is_train_only():
                 continue
             self.full_paths.append(full_path)
-        criterion = task_flow.get_loss()
-        per_sample_criterion = task_flow.get_per_sample_loss(ctx=criterion.get_device_reduced_ctx())
+        criterion = task_flow.get_criterion()
+        per_sample_criterion = task_flow.get_per_sample_criterion(ctx=criterion.get_device_reduced_ctx())
         leaf_losses = criterion.get_leaf_losses()
         metrics = criterion.get_metrics()
         self._reducing_func = partial(reduce_on_device,
